/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;n&&n.fn&&n.fn.select2&&n.fn.select2.amd&&(e=n.fn.select2.amd),e.define("select2/i18n/sr",[],function(){function t(n,e,t,r){return n%10==1&&n%100!=11?e:2<=n%10&&n%10<=4&&(n%100<12||14<n%100)?t:r}return{errorLoading:function(){return"Preuzimanje nije uspelo."},inputTooLong:function(n){var e=n.input.length-n.maximum;return"Obrišite "+e+" simbol"+t(e,"","a","a")},inputTooShort:function(n){var e=n.minimum-n.input.length;return"Ukucajte bar još "+e+" simbol"+t(e,"","a","a")},loadingMore:function(){return"Preuzimanje još rezultata…"},maximumSelected:function(n){return"Možete izabrati samo "+n.maximum+" stavk"+t(n.maximum,"u","e","i")},noResults:function(){return"Ništa nije pronađeno"},searching:function(){return"Pretraga…"},removeAllItems:function(){return"Уклоните све ставке"}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"sr"});document.dispatchEvent(event);