.select2-container {
    min-width: 20em;
}

ul li.select2-selection__choice,
ul li.select2-search {
    /* Cancel out django's style */
    list-style-type: none;
}

.errors .select2-selection {
    /* Highlight select box with error */
    border-color: #ba2121;
}
