/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(e){var n;e&&e.fn&&e.fn.select2&&e.fn.select2.amd&&(n=e.fn.select2.amd),n.define("select2/i18n/sk",[],function(){var t={2:function(e){return e?"dva":"dve"},3:function(){return"tri"},4:function(){return"štyri"}};return{errorLoading:function(){return"Výsledky sa nepodarilo načítať."},inputTooLong:function(e){var n=e.input.length-e.maximum;return 1==n?"Prosím, zadajte o jeden znak menej":2<=n&&n<=4?"Prosím, zadajte o "+t[n](!0)+" znaky menej":"Prosím, zadajte o "+n+" znakov menej"},inputTooShort:function(e){var n=e.minimum-e.input.length;return 1==n?"Prosím, zadajte ešte jeden znak":n<=4?"Prosím, zadajte ešte ďalšie "+t[n](!0)+" znaky":"Prosím, zadajte ešte ďalších "+n+" znakov"},loadingMore:function(){return"Načítanie ďalších výsledkov…"},maximumSelected:function(e){return 1==e.maximum?"Môžete zvoliť len jednu položku":2<=e.maximum&&e.maximum<=4?"Môžete zvoliť najviac "+t[e.maximum](!1)+" položky":"Môžete zvoliť najviac "+e.maximum+" položiek"},noResults:function(){return"Nenašli sa žiadne položky"},searching:function(){return"Vyhľadávanie…"},removeAllItems:function(){return"Odstráňte všetky položky"}}}),n.define,n.require},event=new CustomEvent("dal-language-loaded",{lang:"sk"});document.dispatchEvent(event);