/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;n&&n.fn&&n.fn.select2&&n.fn.select2.amd&&(e=n.fn.select2.amd),e.define("select2/i18n/lt",[],function(){function t(n,e,t,i){return n%10==1&&(n%100<11||19<n%100)?e:2<=n%10&&n%10<=9&&(n%100<11||19<n%100)?t:i}return{inputTooLong:function(n){var e=n.input.length-n.maximum;return"Pašalinkite "+e+" simbol"+t(e,"į","ius","ių")},inputTooShort:function(n){var e=n.minimum-n.input.length;return"Įrašykite dar "+e+" simbol"+t(e,"į","ius","ių")},loadingMore:function(){return"Kraunama daugiau rezultatų…"},maximumSelected:function(n){return"Jūs galite pasirinkti tik "+n.maximum+" element"+t(n.maximum,"ą","us","ų")},noResults:function(){return"Atitikmenų nerasta"},searching:function(){return"Ieškoma…"},removeAllItems:function(){return"Pašalinti visus elementus"}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"lt"});document.dispatchEvent(event);