/*! Select2 4.0.13 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;n&&n.fn&&n.fn.select2&&n.fn.select2.amd&&(e=n.fn.select2.amd),e.define("select2/i18n/pl",[],function(){function t(n,e){return 1===n?e[0]:1<n&&n<=4?e[1]:5<=n?e[2]:void 0}var a=["znak","znaki","znaków"],e=["element","elementy","elementów"];return{errorLoading:function(){return"Nie można załadować wyników."},inputTooLong:function(n){var e=n.input.length-n.maximum;return"Usuń "+e+" "+t(e,a)},inputTooShort:function(n){var e=n.minimum-n.input.length;return"Podaj przynajmniej "+e+" "+t(e,a)},loadingMore:function(){return"Trwa ładowanie…"},maximumSelected:function(n){return"Możesz zaznaczyć tylko "+n.maximum+" "+t(n.maximum,e)},noResults:function(){return"Brak wyników"},searching:function(){return"Trwa wyszukiwanie…"},removeAllItems:function(){return"Usuń wszystkie przedmioty"}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"pl"});document.dispatchEvent(event);